@@ -316,8 +316,8 @@ sub dlg_file
 sub open_help
 {       
    my ( $self, $address) = @_;
-   $address = 'index.pod' unless defined $address;
-   $::application->open_help($address);
+   $address = 'index' unless defined $address;
+   $::application->open_help('App::PLab::' . $address);
 }   
 
 # WIN
